package com.seeyon.apps.doc.manager;

import com.seeyon.apps.doc.dao.DocMetadataDao;
import com.seeyon.apps.doc.dao.DocResourceDao;
import com.seeyon.apps.doc.dao.DocVersionInfoDao;
import com.seeyon.apps.doc.manager.ContentTypeManager;
import com.seeyon.apps.doc.manager.DocMetadataManager;
import com.seeyon.apps.doc.manager.MetadataDefManager;
import com.seeyon.apps.doc.po.DocMetadataDefinitionPO;
import com.seeyon.apps.doc.po.DocMetadataObjectPO;
import com.seeyon.apps.doc.po.DocMetadataOptionPO;
import com.seeyon.apps.doc.po.DocResourcePO;
import com.seeyon.apps.doc.po.DocTypeDetailPO;
import com.seeyon.apps.doc.po.DocVersionInfoPO;
import com.seeyon.apps.doc.util.Constants;
import com.seeyon.apps.doc.util.DocMVCUtils;
import com.seeyon.apps.doc.util.DocSearchHqlUtils;
import com.seeyon.apps.edoc.api.EdocApi;
import com.seeyon.apps.edoc.bo.EdocElementBO;
import com.seeyon.ctp.common.ctpenumnew.EnumNameEnum;
import com.seeyon.ctp.common.ctpenumnew.manager.EnumManager;
import com.seeyon.ctp.common.exceptions.BusinessException;
import com.seeyon.ctp.common.i18n.ResourceUtil;
import com.seeyon.ctp.common.taglibs.functions.Functions;
import com.seeyon.ctp.util.CommonTools;
import com.seeyon.ctp.util.DBAgent;
import com.seeyon.ctp.util.Strings;
import com.seeyon.ctp.util.annotation.AjaxAccess;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import org.apache.commons.collections.CollectionUtils;

public class DocMetadataManagerImpl implements DocMetadataManager {

   private DocResourceDao docResourceDao;
   private DocVersionInfoDao docVersionInfoDao;
   private DocMetadataDao docMetadataDao;
   private ContentTypeManager contentTypeManager;
   private MetadataDefManager metadataDefManager;
   private EnumManager enumManagerNew;
   private EdocApi edocApi;


   public Map getDocMetadatas(List drIds) {
      HashMap result = new HashMap();
      if(CollectionUtils.isNotEmpty(drIds)) {
         List metadatas = this.docMetadataDao.find("from DocMetadata where docResourceId in (:drIds)", -1, -1, CommonTools.newHashMap("drIds", drIds), new Object[0]);
         if(CollectionUtils.isNotEmpty(metadatas)) {
            Iterator var4 = metadatas.iterator();

            while(var4.hasNext()) {
               Map metadata = (Map)var4.next();
               result.put((Long)metadata.get("docResourceId"), metadata);
            }

            return result;
         }
      }

      return null;
   }

   public Map getEDocMetadatas(List edocIds, List dmds) {
      if(CollectionUtils.isNotEmpty(edocIds)) {
         ArrayList poNames = new ArrayList();
         ArrayList aliasPoNames = new ArrayList();
         ArrayList fieldNames = new ArrayList();
         ArrayList aliasFieldNames = new ArrayList();
         Iterator hql = dmds.iterator();

         while(hql.hasNext()) {
            DocMetadataDefinitionPO metadatas = (DocMetadataDefinitionPO)hql.next();
            EdocElementBO metadataMap = metadatas.getEdocElement();
            if(metadatas.getIsEdocElement() && metadataMap != null) {
               String aliasTable = "_" + metadataMap.getPoName().toLowerCase();
               if(!poNames.contains(metadataMap.getPoName())) {
                  poNames.add(metadataMap.getPoName());
                  aliasPoNames.add(aliasTable);
               }

               String map = metadataMap.getPoFieldName();
               String tempFieldName = this.edocApi.getEdocElementBOFieldName(metadataMap.getPoFieldName());
               if(!Strings.isBlank(tempFieldName)) {
                  map = tempFieldName;
               }

               fieldNames.add(aliasTable + "." + map);
               aliasFieldNames.add(metadatas.getPhysicalName());
            }
         }

         if(!poNames.isEmpty()) {
            StringBuilder var13 = new StringBuilder();
            var13.append("select new map(");
            var13.append((String)aliasPoNames.get(0)).append(".");
            var13.append(DocSearchHqlUtils.EDOCTABPKS[Arrays.binarySearch(DocSearchHqlUtils.EDOCTABNAMES, poNames.get(0), new DocMetadataManagerImpl.StringComparator(null))]).append(" as id,");

            int var14;
            for(var14 = 0; var14 < fieldNames.size(); ++var14) {
               if(var14 != 0) {
                  var13.append(",");
               }

               var13.append((String)fieldNames.get(var14)).append(" as ").append((String)aliasFieldNames.get(var14));
            }

            var13.append(") from ");

            for(var14 = 0; var14 < poNames.size(); ++var14) {
               if(var14 != 0) {
                  var13.append(",");
               }

               var13.append((String)poNames.get(var14)).append(" ").append((String)aliasPoNames.get(var14));
            }

            var13.append(" where ");

            for(var14 = 0; var14 < aliasPoNames.size(); ++var14) {
               if(var14 != 0) {
                  var13.append(" = ");
               }

               int var15 = Arrays.binarySearch(DocSearchHqlUtils.EDOCTABNAMES, poNames.get(var14), new DocMetadataManagerImpl.StringComparator(null));
               var13.append((String)aliasPoNames.get(var14)).append(".").append(DocSearchHqlUtils.EDOCTABPKS[var15]);
               if((var14 + 1) % 2 == 0) {
                  var13.append(" and ");
               }
            }

            if(aliasPoNames.size() == 1) {
               var13.append(" in (:ids) ");
            } else {
               var14 = Arrays.binarySearch(DocSearchHqlUtils.EDOCTABNAMES, poNames.get(0), new DocMetadataManagerImpl.StringComparator(null));
               var13.append((String)aliasPoNames.get(0)).append(".").append(DocSearchHqlUtils.EDOCTABPKS[var14]).append(" in(:ids) ");
            }

            List var18 = DBAgent.find(var13.toString(), CommonTools.newHashMap("ids", edocIds));
            HashMap var16 = new HashMap();
            Iterator var17 = var18.iterator();

            while(var17.hasNext()) {
               Map var19 = (Map)var17.next();
               var16.put((Long)var19.get("id"), var19);
            }

            return var16;
         }
      }

      return Collections.emptyMap();
   }

   public static void main(String[] args) {
      ArrayList dmds = new ArrayList();
      DocMetadataDefinitionPO d3 = new DocMetadataDefinitionPO();
      d3.setIdIfNew();
      d3.setPhysicalName("fieldName21");
      d3.setIsEdocElement(true);
      EdocElementBO e3 = new EdocElementBO();
      e3.setId(Long.valueOf(1L));
      e3.setFieldName("fieldeName21");
      e3.setPoName("EdocSummaryExtend");
      d3.setEdocElement(e3);
      dmds.add(d3);
      DocMetadataDefinitionPO d4 = new DocMetadataDefinitionPO();
      d4.setIdIfNew();
      d4.setPhysicalName("fieldName31");
      d4.setIsEdocElement(false);
      EdocElementBO e4 = new EdocElementBO();
      e4.setId(Long.valueOf(1L));
      e4.setFieldName("fieldeName31");
      e4.setPoName("EdocSummaryExtend");
      d4.setEdocElement(e4);
      dmds.add(d4);
      DocMetadataManagerImpl l = new DocMetadataManagerImpl();
      l.getEDocMetadatas(CommonTools.newArrayList(new Long[]{Long.valueOf(1L), Long.valueOf(2L), Long.valueOf(3L)}), dmds);
   }

   @AjaxAccess
   public List getContentPropertiesForAjax(String resourceId) {
      DocResourcePO doc = (DocResourcePO)this.docResourceDao.get(Long.valueOf(resourceId));
      List contentProperties = this.getContentProperties((DocResourcePO)doc);
      if(Strings.isNotEmpty(contentProperties)) {
         contentProperties.forEach(accept<invokedynamic>(this, doc));
      }

      return contentProperties;
   }

   public List getContentProperties(Long resourceId) {
      DocResourcePO doc = (DocResourcePO)this.docResourceDao.get(resourceId);
      return this.getContentProperties((DocResourcePO)doc);
   }

   public List getContentProperties(DocResourcePO doc) {
      Map map = this.docMetadataDao.getDocMetadataMap(doc.getId());
      long ctypeid = doc.getFrType();
      ArrayList list = new ArrayList();
      List dtds = this.contentTypeManager.getContentTypeDetails(ctypeid);
      if(CollectionUtils.isNotEmpty(dtds)) {
         Iterator var7 = dtds.iterator();

         while(var7.hasNext()) {
            DocTypeDetailPO dtd = (DocTypeDetailPO)var7.next();
            long metadataDefId = dtd.getMetadataDefId();
            DocMetadataDefinitionPO metadataDef = this.metadataDefManager.getMetadataDefById(Long.valueOf(metadataDefId));
            DocMetadataObjectPO meta = new DocMetadataObjectPO();
            meta.setMetadataDefId(metadataDef.getId().longValue());
            meta.setMetadataName(dtd.getName());
            String pname = metadataDef.getPhysicalName();
            meta.setMetadataValue(map.get(pname));
            meta.setOrderNum(dtd.getOrderNum());
            meta.setMetadataType(metadataDef.getType());
            meta.setPhysicalName(pname);
            meta.setOptionType(metadataDef.getOptionType());
            if(meta.getMetadataType() == 8 && meta.getMetadataValue() != null) {
               meta.setShowName(Functions.showMemberName((Long)meta.getMetadataValue()));
            }

            if(meta.getMetadataType() == 9 && meta.getMetadataValue() != null) {
               meta.setShowName(Functions.showDepartmentName((Long)meta.getMetadataValue()));
            }

            ArrayList optionList = new ArrayList();
            if(CollectionUtils.isNotEmpty(metadataDef.getMetadataOption())) {
               optionList = new ArrayList(metadataDef.getMetadataOption());
            }

            meta.setOptionList(optionList);
            list.add(meta);
         }
      }

      return list;
   }

   public DocResourcePO getDocResourceDetail(Long resourceId) {
      DocResourcePO doc = (DocResourcePO)this.docResourceDao.get(resourceId);
      this.setMetaDataInfo4DocResouce(doc);
      return doc;
   }

   private void setMetaDataInfo4DocResouce(DocResourcePO doc) {
      List cd = this.contentTypeManager.getContentTypeDetails(doc.getFrType());
      ArrayList list = new ArrayList();
      HashMap metamap = new HashMap();
      Map map = this.docMetadataDao.getDocMetadataMap(doc.getId());
      Iterator var6 = cd.iterator();

      while(var6.hasNext()) {
         DocTypeDetailPO cds = (DocTypeDetailPO)var6.next();
         DocMetadataObjectPO meta = new DocMetadataObjectPO();
         long metadataDefId = cds.getMetadataDefId();
         DocMetadataDefinitionPO metadataDef = this.metadataDefManager.getMetadataDefById(Long.valueOf(metadataDefId));
         if(metadataDef != null && !metadataDef.getIsDefault()) {
            meta.setReadOnly(cds.getReadOnly());
            meta.setMetadataDefId(metadataDef.getId().longValue());
            meta.setMetadataName(cds.getName());
            String pname = metadataDef.getPhysicalName();
            meta.setMetadataValue(map.get(pname));
            meta.setOrderNum(cds.getOrderNum());
            meta.setMetadataType(metadataDef.getType());
            meta.setPhysicalName(pname);
            meta.setOptionType(metadataDef.getOptionType());
            ArrayList optionList = new ArrayList();
            Set optionSet = metadataDef.getMetadataOption();
            if(optionSet != null) {
               Iterator var15 = optionSet.iterator();

               while(var15.hasNext()) {
                  DocMetadataOptionPO option = (DocMetadataOptionPO)var15.next();
                  optionList.add(option);
               }
            }

            meta.setOptionList(optionList);
            list.add(meta);
            metamap.put(Long.valueOf(meta.getMetadataDefId()), meta.getMetadataValue());
         }
      }

      doc.setMetadataList(list);
      doc.setMetadataMap(metamap);
   }

   public DocResourcePO getDocVersionInfoDetail(Long docVersionId) {
      DocVersionInfoPO dvi = (DocVersionInfoPO)this.docVersionInfoDao.get(docVersionId);
      DocResourcePO doc = dvi.getDocResourceFromXml();
      doc.setId(dvi.getId());
      this.setMetaDataInfo4DocResouce(doc);
      return doc;
   }

   public void addMetadata(Long docResourceId, Map paramap) {
      paramap.put("docResourceId", docResourceId);
      this.docMetadataDao.insertDocMetadata(paramap);
   }

   public void updateMetadata(Long docResourceId, Map paramap) {
      paramap.put("docResourceId", docResourceId);
      this.docMetadataDao.updateDocMetadata(paramap);
   }

   public void bulkUpdateMetadata(List docResourceIds, Map paramap) {
      this.docMetadataDao.bulkUpdateDocMetadata(docResourceIds, paramap);
   }

   public void deleteMetadata(DocResourcePO dr) {
      if(dr.getIsFolder()) {
         List dlist = this.docResourceDao.getSubDocResources(dr);
         List drIds = CommonTools.getIds(dlist);
         this.docMetadataDao.deleteDocMetadata(drIds);
      } else {
         this.docMetadataDao.deleteDocMetadata(dr.getId());
      }

   }

   public void deleteMetadata(List docList) throws BusinessException {
      if(!Strings.isEmpty(docList)) {
         ArrayList list = new ArrayList();
         Iterator var3 = docList.iterator();

         while(var3.hasNext()) {
            DocResourcePO doc = (DocResourcePO)var3.next();
            if(doc.getIsFolder()) {
               throw new BusinessException("not excepted invoke: doc is folder");
            }

            list.add(doc.getId());
         }

         this.docMetadataDao.deleteDocMetadata(list);
      }
   }

   public Map getDocMetadataMap(Long resourceId) {
      return this.docMetadataDao.getDocMetadataMap(resourceId);
   }

   public void setDocMetadataDao(DocMetadataDao docMetadataDao) {
      this.docMetadataDao = docMetadataDao;
   }

   public void setDocResourceDao(DocResourceDao docResourceDao) {
      this.docResourceDao = docResourceDao;
   }

   public void setContentTypeManager(ContentTypeManager contentTypeManager) {
      this.contentTypeManager = contentTypeManager;
   }

   public void setMetadataDefManager(MetadataDefManager metadataDefManager) {
      this.metadataDefManager = metadataDefManager;
   }

   public void setDocVersionInfoDao(DocVersionInfoDao docVersionInfoDao) {
      this.docVersionInfoDao = docVersionInfoDao;
   }

   public void setEdocApi(EdocApi edocApi) {
      this.edocApi = edocApi;
   }

   public void setEnumManagerNew(EnumManager enumManager) {
      this.enumManagerNew = enumManager;
   }

   // $FF: synthetic method
   private void lambda$getContentPropertiesForAjax$0(DocResourcePO doc, DocMetadataObjectPO docMetadataObjectPO) {
      docMetadataObjectPO.setMetadataName(ResourceUtil.getString(docMetadataObjectPO.getMetadataName()));
      DocMetadataDefinitionPO metadataDef = this.metadataDefManager.getMetadataDefById(Long.valueOf(docMetadataObjectPO.getMetadataDefId()));
      Object value = docMetadataObjectPO.getMetadataValue();
      if(value != null && Strings.isNotBlank(value.toString())) {
         EnumNameEnum mne = Constants.getMetadataNameEnum(metadataDef.getName(), value.toString(), doc.getFrType());
         String value1;
         if(mne != null) {
            value1 = this.enumManagerNew.getEnumItemLabel(mne, value.toString());
            value = value1 == null?"":value1;
         }

         value1 = DocMVCUtils.getDisplayName4MetadataDefinition(String.valueOf(value), new Object[]{value.toString()});
         docMetadataObjectPO.setMetadataValue(value1);
      }

   }

   private class StringComparator implements Comparator {

      private StringComparator() {
      }

      public int compare(String s1, String s2) {
         return s1.equals(s2)?0:-1;
      }

      // $FF: synthetic method
      StringComparator(Object x1) {
         this();
      }
   }
}
